@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,7 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/embed/XTransactedObject.hpp>
 #include <tools/urlobj.hxx>
@@ -39,16 +39,14 @@
 
 #include <comphelper/storagehelper.hxx>
 #include <doc.hxx>
-#ifndef _DOCSH_HXX
+#include <IDocumentUndoRedo.hxx>
 #include <docsh.hxx>
-#endif
 #include <pam.hxx>
 #include <swblocks.hxx>
 #include <ndtxt.hxx>
 #include <shellio.hxx>
 #include <poolfmt.hxx>
 #include <SwXMLTextBlocks.hxx>
-#include <errhdl.hxx>
 #include <SwXMLBlockImport.hxx>
 #include <SwXMLBlockExport.hxx>
 #include <swerror.h>
@@ -72,16 +70,16 @@ void SwXMLTextBlocks::ResetBlockMode ( )
 }
 
 SwXMLTextBlocks::SwXMLTextBlocks( const String& rFile )
-: SwImpBlocks( rFile ), bAutocorrBlock( FALSE ), nFlags ( 0 )
+: SwImpBlocks( rFile ), bAutocorrBlock( sal_False ), nFlags ( 0 )
 {
     SwDocShell* pDocSh = new SwDocShell ( SFX_CREATE_MODE_INTERNAL );
     if( !pDocSh->DoInitNew( 0 ) )
         return;
-    bReadOnly = TRUE;
+    bReadOnly = sal_True;
     pDoc = pDocSh->GetDoc();
     xDocShellRef = pDocSh;
     pDoc->SetOle2Link( Link() );
-    pDoc->DoUndo( FALSE );		// always FALSE
+    pDoc->GetIDocumentUndoRedo().DoUndo(false);
     pDoc->acquire();
     uno::Reference< embed::XStorage > refStg;
     if( !aDateModified.GetDate() || !aTimeModified.GetTime() )
@@ -89,7 +87,7 @@ SwXMLTextBlocks::SwXMLTextBlocks( const String& rFile )
     try
     {
         refStg  = comphelper::OStorageHelper::GetStorageFromURL( rFile, embed::ElementModes::READWRITE );
-        bReadOnly = FALSE;
+        bReadOnly = sal_False;
     }
     catch( const uno::Exception& )
     {
@@ -103,33 +101,33 @@ SwXMLTextBlocks::SwXMLTextBlocks( const String& rFile )
         }
         catch( const uno::Exception& )
         {
-            DBG_ERROR("exception while creating AutoText storage");
+            OSL_FAIL("exception while creating AutoText storage");
         }
     }
     InitBlockMode ( refStg );
     ReadInfo();
     ResetBlockMode ();
-    bInfoChanged = FALSE;
+    bInfoChanged = sal_False;
 }
 
 SwXMLTextBlocks::SwXMLTextBlocks( const uno::Reference < embed::XStorage >& rStg, const String& rName )
 : SwImpBlocks( rName )
-, bAutocorrBlock( TRUE )
+, bAutocorrBlock( sal_True )
 , nFlags ( 0 )
 {
     SwDocShell* pDocSh = new SwDocShell ( SFX_CREATE_MODE_INTERNAL );
     if( !pDocSh->DoInitNew( 0 ) )
         return;
-    bReadOnly = FALSE;
+    bReadOnly = sal_False;
     pDoc = pDocSh->GetDoc();
     xDocShellRef = pDocSh;
     pDoc->SetOle2Link( Link() );
-    pDoc->DoUndo( FALSE );
+    pDoc->GetIDocumentUndoRedo().DoUndo(false);
     pDoc->acquire();
 
     InitBlockMode ( rStg );
     ReadInfo();
-    bInfoChanged = FALSE;
+    bInfoChanged = sal_False;
 }
 
 SwXMLTextBlocks::~SwXMLTextBlocks()
@@ -153,35 +151,35 @@ void SwXMLTextBlocks::ClearDoc()
     pDoc->ClearDoc();
     pDocShell->ClearEmbeddedObjects();
 }
-void SwXMLTextBlocks::AddName( const String& rShort, const String& rLong, BOOL bOnlyTxt )
+void SwXMLTextBlocks::AddName( const String& rShort, const String& rLong, sal_Bool bOnlyTxt )
 {
-    USHORT nIdx = GetIndex( rShort );
+    sal_uInt16 nIdx = GetIndex( rShort );
     SwBlockName* pNew = NULL;
-    if( nIdx != (USHORT) -1 )
+    if( nIdx != (sal_uInt16) -1 )
         aNames.DeleteAndDestroy( nIdx );
 
     GeneratePackageName( rShort, aPackageName );
     pNew = new SwBlockName( rShort, rLong, aPackageName );
 
-    pNew->bIsOnlyTxtFlagInit = TRUE;
+    pNew->bIsOnlyTxtFlagInit = sal_True;
     pNew->bIsOnlyTxt = bOnlyTxt;
     aNames.C40_PTR_INSERT( SwBlockName, pNew );
-    bInfoChanged = TRUE;
+    bInfoChanged = sal_True;
 }
 void SwXMLTextBlocks::AddName( const String& rShort, const String& rLong,
-                           const String& rPackageName, BOOL bOnlyTxt )
+                           const String& rPackageName, sal_Bool bOnlyTxt )
 {
-    USHORT nIdx = GetIndex( rShort );
-    if( nIdx != (USHORT) -1 )
+    sal_uInt16 nIdx = GetIndex( rShort );
+    if( nIdx != (sal_uInt16) -1 )
         aNames.DeleteAndDestroy( nIdx );
     SwBlockName* pNew = new SwBlockName( rShort, rLong, rPackageName );
-    pNew->bIsOnlyTxtFlagInit = TRUE;
+    pNew->bIsOnlyTxtFlagInit = sal_True;
     pNew->bIsOnlyTxt = bOnlyTxt;
     aNames.C40_PTR_INSERT( SwBlockName, pNew );
-    bInfoChanged = TRUE;
+    bInfoChanged = sal_True;
 }
 
-ULONG SwXMLTextBlocks::Delete( USHORT n )
+sal_uLong SwXMLTextBlocks::Delete( sal_uInt16 n )
 {
     String aPckName (aNames[ n ]->aPackageName);
     uno::Reference < container::XNameAccess > xAccess( xBlkRoot, uno::UNO_QUERY );
@@ -204,7 +202,7 @@ ULONG SwXMLTextBlocks::Delete( USHORT n )
     return 0;
 }
 
-ULONG SwXMLTextBlocks::Rename( USHORT nIdx, const String& rNewShort, const String& )
+sal_uLong SwXMLTextBlocks::Rename( sal_uInt16 nIdx, const String& rNewShort, const String& )
 {
     DBG_ASSERT( xBlkRoot.is(), "No storage set" );
     if(!xBlkRoot.is())
@@ -245,17 +243,17 @@ ULONG SwXMLTextBlocks::Rename( USHORT nIdx, const String& rNewShort, const Strin
     return 0;
 }
 
-ULONG SwXMLTextBlocks::CopyBlock( SwImpBlocks& rDestImp, String& rShort,
+sal_uLong SwXMLTextBlocks::CopyBlock( SwImpBlocks& rDestImp, String& rShort,
                                                     const String& rLong)
 {
-    ULONG nError = 0;
-    OpenFile(TRUE);
-    rDestImp.OpenFile(FALSE);
+    sal_uLong nError = 0;
+    OpenFile(sal_True);
+    rDestImp.OpenFile(sal_False);
     String aGroup( rShort );
-    BOOL bTextOnly = IsOnlyTextBlock ( rShort ) ;//pImp->pBlkRoot->IsStream( aGroup );
-    USHORT nIndex = GetIndex ( rShort );
+    sal_Bool bTextOnly = IsOnlyTextBlock ( rShort ) ;//pImp->pBlkRoot->IsStream( aGroup );
+    sal_uInt16 nIndex = GetIndex ( rShort );
     String sDestShortName( GetPackageName (nIndex) );
-    USHORT nIdx = 0;
+    sal_uInt16 nIdx = 0;
 
     DBG_ASSERT( xBlkRoot.is(), "No storage set" );
     if(!xBlkRoot.is())
@@ -279,10 +277,6 @@ ULONG SwXMLTextBlocks::CopyBlock( SwImpBlocks& rDestImp, String& rShort,
     {
         uno::Reference < embed::XStorage > rSourceRoot = xBlkRoot->openStorageElement( aGroup, embed::ElementModes::READ );
         uno::Reference < embed::XStorage > rDestRoot = ((SwXMLTextBlocks&)rDestImp).xBlkRoot->openStorageElement( sDestShortName, embed::ElementModes::READWRITE );
-        //if(!rSourceRoot.Is())
-        //    nError = ERR_SWG_READ_ERROR;
-        //else
-        //{
         rSourceRoot->copyToStorage( rDestRoot );
     }
     catch ( uno::Exception& )
@@ -290,26 +284,9 @@ ULONG SwXMLTextBlocks::CopyBlock( SwImpBlocks& rDestImp, String& rShort,
         nError = ERR_SWG_WRITE_ERROR;
     }
 
-    /* I think this should work now that text only blocks are in sub-storages as well
-    else
-    {
-        SvStorageStreamRef rSourceStream = xBlkRoot->OpenStream( aGroup, STREAM_STGREAD );
-        SvStorageStreamRef rDestStream = ((SwXMLTextBlocks&)rDestImp).xBlkRoot-> OpenStream( sDestShortName, STREAM_STGWRITE );
-        if(!rDestStream.Is())
-            nError = ERR_SWG_WRITE_ERROR;
-        else
-        {
-            if(!rSourceStream->CopyTo(&rDestStream))
-                nError = ERR_SWG_WRITE_ERROR;
-            else
-                rDestStream->Commit();
-        }
-    }
-    */
     if(!nError)
     {
         rShort = sDestShortName;
-        //((SwXMLTextBlocks&)rDestImp).xBlkRoot->Commit();
         ((SwXMLTextBlocks&)rDestImp).AddName( rShort, rLong, bTextOnly );
         ((SwXMLTextBlocks&)rDestImp).MakeBlockList();
     }
@@ -319,19 +296,12 @@ ULONG SwXMLTextBlocks::CopyBlock( SwImpBlocks& rDestImp, String& rShort,
 }
 
 
-ULONG SwXMLTextBlocks::StartPutBlock( const String& rShort, const String& rPackageName )
+sal_uLong SwXMLTextBlocks::StartPutBlock( const String& rShort, const String& rPackageName )
 {
     DBG_ASSERT( xBlkRoot.is(), "No storage set" );
     if(!xBlkRoot.is())
         return 0;
     GetIndex ( rShort );
-    /*
-    if( xBlkRoot->IsContained( rPackageName ) )
-    {
-        xBlkRoot->Remove( rPackageName );
-        xBlkRoot->Commit();
-    }
-    */
     try
     {
         xRoot = xBlkRoot->openStorageElement( rPackageName, embed::ElementModes::READWRITE );
@@ -346,20 +316,20 @@ ULONG SwXMLTextBlocks::StartPutBlock( const String& rShort, const String& rPacka
     }
     return 0;
 }
-ULONG SwXMLTextBlocks::BeginPutDoc( const String& rShort, const String& rLong )
+sal_uLong SwXMLTextBlocks::BeginPutDoc( const String& rShort, const String& rLong )
 {
     // In der Basisklasse ablegen!
     aShort = rShort;
     aLong = rLong;
     GeneratePackageName( rShort, aPackageName );
-    SetIsTextOnly( rShort, FALSE);
+    SetIsTextOnly( rShort, sal_False);
     return StartPutBlock (rShort, aPackageName);
 }
 
-ULONG SwXMLTextBlocks::PutBlock( SwPaM& , const String& )
+sal_uLong SwXMLTextBlocks::PutBlock( SwPaM& , const String& )
 {
-    ULONG nRes = 0;
-    USHORT nCommitFlags = nFlags & (SWXML_CONVBLOCK|SWXML_NOROOTCOMMIT);
+    sal_uLong nRes = 0;
+    sal_uInt16 nCommitFlags = nFlags & (SWXML_CONVBLOCK|SWXML_NOROOTCOMMIT);
 
     nFlags |= nCommitFlags;
 
@@ -432,58 +402,50 @@ ULONG SwXMLTextBlocks::PutBlock( SwPaM& , const String& )
     }
 
     //TODO/LATER: error handling
-    /*
-    ULONG nErr = xBlkRoot->GetError();
-    if( nErr == SVSTREAM_DISK_FULL )
-        nRes = ERR_W4W_WRITE_FULL;
-    else if( nErr != SVSTREAM_OK )
-        nRes = ERR_SWG_WRITE_ERROR;
-    nFlags |= nCommitFlags;
-    return nErr;*/
     return 0;
 }
 
-ULONG SwXMLTextBlocks::PutDoc()
+sal_uLong SwXMLTextBlocks::PutDoc()
 {
     SwPaM* pPaM = MakePaM();
-    ULONG nErr = PutBlock(*pPaM, aLong);
+    sal_uLong nErr = PutBlock(*pPaM, aLong);
     delete pPaM;
     return nErr;
 }
 
-ULONG SwXMLTextBlocks::GetText( USHORT nIdx, String& rText )
+sal_uLong SwXMLTextBlocks::GetText( sal_uInt16 nIdx, String& rText )
 {
     return GetBlockText( aNames[ nIdx ]->aShort, rText );
 }
 
-ULONG SwXMLTextBlocks::GetText( const String& rShort, String& rText )
+sal_uLong SwXMLTextBlocks::GetText( const String& rShort, String& rText )
 {
     return GetBlockText( rShort, rText );
 }
 
 
-ULONG SwXMLTextBlocks::MakeBlockList()
+sal_uLong SwXMLTextBlocks::MakeBlockList()
 {
     WriteInfo();
     return 0;
 }
 
-BOOL SwXMLTextBlocks::PutMuchEntries( BOOL bOn )
+sal_Bool SwXMLTextBlocks::PutMuchEntries( sal_Bool bOn )
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
     if( bOn )
     {
         if( bInPutMuchBlocks )
         {
-            ASSERT( !this, "verschachtelte Aufrufe sind nicht erlaubt" );
+            OSL_ENSURE( !this, "verschachtelte Aufrufe sind nicht erlaubt" );
         }
         else if( !IsFileChanged() )
         {
-            bRet = 0 == OpenFile( FALSE );
+            bRet = 0 == OpenFile( sal_False );
             if( bRet )
             {
                 nFlags |= SWXML_NOROOTCOMMIT;
-                bInPutMuchBlocks = TRUE;
+                bInPutMuchBlocks = sal_True;
             }
         }
     }
@@ -500,8 +462,8 @@ BOOL SwXMLTextBlocks::PutMuchEntries( BOOL bOn )
                 MakeBlockList();
                 CloseFile();
                 Touch();
-                bInPutMuchBlocks = FALSE;
-                bRet = TRUE;
+                bInPutMuchBlocks = sal_False;
+                bRet = sal_True;
             }
             catch (uno::Exception&)
             {
@@ -511,11 +473,11 @@ BOOL SwXMLTextBlocks::PutMuchEntries( BOOL bOn )
     return bRet;
 }
 
-ULONG SwXMLTextBlocks::OpenFile( BOOL bRdOnly )
+sal_uLong SwXMLTextBlocks::OpenFile( sal_Bool bRdOnly )
 {
     if( bAutocorrBlock )
         return 0;
-    ULONG nRet = 0;
+    sal_uLong nRet = 0;
     try
     {
         uno::Reference < embed::XStorage > refStg  = comphelper::OStorageHelper::GetStorageFromURL( aFile,
@@ -541,34 +503,34 @@ void SwXMLTextBlocks::CloseFile()
     }
 }
 
-void SwXMLTextBlocks::SetIsTextOnly( const String& rShort, BOOL bNewValue )
+void SwXMLTextBlocks::SetIsTextOnly( const String& rShort, sal_Bool bNewValue )
 {
-    USHORT nIdx = GetIndex ( rShort );
-    if (nIdx != (USHORT) -1  && nIdx != USHRT_MAX)
+    sal_uInt16 nIdx = GetIndex ( rShort );
+    if (nIdx != (sal_uInt16) -1  && nIdx != USHRT_MAX)
         aNames[nIdx]->bIsOnlyTxt = bNewValue;
 }
 
-void SwXMLTextBlocks::SetIsTextOnly( USHORT nIdx, BOOL bNewValue )
+void SwXMLTextBlocks::SetIsTextOnly( sal_uInt16 nIdx, sal_Bool bNewValue )
 {
     aNames[nIdx]->bIsOnlyTxt = bNewValue;
 }
 
-BOOL SwXMLTextBlocks::IsOnlyTextBlock( const String& rShort ) const
+sal_Bool SwXMLTextBlocks::IsOnlyTextBlock( const String& rShort ) const
 {
-    USHORT nIdx = GetIndex ( rShort );
-    BOOL bRet = FALSE;
-    if (nIdx != (USHORT) -1  && nIdx != USHRT_MAX)
+    sal_uInt16 nIdx = GetIndex ( rShort );
+    sal_Bool bRet = sal_False;
+    if (nIdx != (sal_uInt16) -1  && nIdx != USHRT_MAX)
     {
         bRet = aNames[nIdx]->bIsOnlyTxt;
     }
     return bRet;
 }
-BOOL SwXMLTextBlocks::IsOnlyTextBlock( USHORT nIdx ) const
+sal_Bool SwXMLTextBlocks::IsOnlyTextBlock( sal_uInt16 nIdx ) const
 {
     return aNames[nIdx]->bIsOnlyTxt;
 }
 
-BOOL SwXMLTextBlocks::IsFileUCBStorage( const String & rFileName)
+sal_Bool SwXMLTextBlocks::IsFileUCBStorage( const String & rFileName)
 {
     String aName( rFileName );
     INetURLObject aObj( aName );
@@ -581,7 +543,7 @@ BOOL SwXMLTextBlocks::IsFileUCBStorage( const String & rFileName)
     }
 
     SvStream * pStm = ::utl::UcbStreamHelper::CreateStream( aName, STREAM_STD_READ );
-    BOOL bRet = UCBStorage::IsStorageFile( pStm );
+    sal_Bool bRet = UCBStorage::IsStorageFile( pStm );
     delete pStm;
     return bRet;
 }
@@ -607,14 +569,14 @@ void SwXMLTextBlocks::GeneratePackageName ( const String& rShort, String& rPacka
     }
 }
 
-ULONG SwXMLTextBlocks::PutText( const String& rShort, const String& rName,
+sal_uLong SwXMLTextBlocks::PutText( const String& rShort, const String& rName,
                                 const String& rText )
 {
-    ULONG nRes = 0;
+    sal_uLong nRes = 0;
     aShort = rShort;
     aLong = rName;
     aCur = rText;
-    SetIsTextOnly( aShort, TRUE );
+    SetIsTextOnly( aShort, sal_True );
     GeneratePackageName( rShort, aPackageName );
     ClearDoc();
     nRes = PutBlockText( rShort, rName, rText, aPackageName );
@@ -625,7 +587,6 @@ void SwXMLTextBlocks::MakeBlockText( const String& rText )
 {
     SwTxtNode* pTxtNode = pDoc->GetNodes()[ pDoc->GetNodes().GetEndOfContent().
                                         GetIndex() - 1 ]->GetTxtNode();
-    //JP 18.09.98: Bug 56706 - Standard sollte zumindest gesetzt sein!
     if( pTxtNode->GetTxtColl() == pDoc->GetDfltTxtFmtColl() )
         pTxtNode->ChgFmtColl( pDoc->GetTxtCollFromPool( RES_POOLCOLL_STANDARD ));
 
@@ -641,3 +602,5 @@ void SwXMLTextBlocks::MakeBlockText( const String& rText )
         pTxtNode->InsertText( sTemp, aIdx );
     } while ( STRING_NOTFOUND != nPos );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
